@@ -1,7 +1,7 @@
 PL.popN <-
-function(model,tau)
+function(model,tau,D)
   {
-   est1<-PL.popN0(model,tau);
+   est1<-PL.popN0(model,tau,D);
    class(est1)<-"PL.popN"
    est1;
   }
